#[non_exhaustive]pub enum LineStyle {
Simple,
Dashed,
Arrow,
InsideHarpoonCCW,
InsideHarpoonCW,
}Expand description
The style of a line type visual.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Simple
A simple straight continuous line
Dashed
A dashed line
Arrow
A line with an arrowhead on the second point.
InsideHarpoonCCW
A line with half an arrowhead on the second point or along the line. If a polygon is drawn in CCW point order, the harpoon will be on the inside.
InsideHarpoonCW
A line with half an arrowhead on the second point or along the line. If a polygon is drawn in CW point order, the harpoon will be on the inside.