#[repr(u8)]pub enum TextAlignment {
Left = 0,
Center = 1,
Right = 2,
Flexible = 3,
}Expand description
The text alignment relative to a specified spacepoint. All variants center the text vertically.
Variants
Left = 0
Align the left side of the text to the position. Vertically centered.
Center = 1
Center the text on the position.
Right = 2
Align the right side of the text to the position. Vertically centered.
Flexible = 3
Center the text on the position if possible, but the vlogger is allowed to shift the text by a small amount for better readability.