pub enum Visual {
Message,
Label {
x: f64,
y: f64,
z: f64,
alignment: TextAlignment,
},
Point {
x: f64,
y: f64,
z: f64,
style: PointStyle,
},
Line {
x1: f64,
y1: f64,
z1: f64,
x2: f64,
y2: f64,
z2: f64,
style: LineStyle,
},
}Expand description
A visual element to be drawn by the vlogger.
Variants
Message
Just a vlog message to be shown in the vlogger instead of the regular vlogs.
Label
A text label placed in space with the message string.
Fields

alignment: TextAlignmentThe alignment of the text relative to the spacepoint.
Point
A circle/point placed in space.
Fields

style: PointStyleThe drawing style of the circle/point.
Line
A line placed in space.
Fields