Record

Struct Record 

pub struct Record<'a> { /* private fields */ }
The “payload” of a vlog command.

Use

Record structures are passed as parameters to the vlog method of the VLog trait. Vlogger implementors manipulate these structures in order to display vlog commands. Records are automatically created by the macros and so are not seen by vlog users.

Implementations

Source

impl<'a> Record<'a>

pub fn builder() -> RecordBuilder<'a>

Returns a new builder.

pub fn args(&self) -> &Arguments<'a>

The message/label text.

pub fn visual(&self) -> &Visual

The visual element to draw.

pub fn color(&self) -> &Color

The color of the visual element.

pub fn size(&self) -> f64

The size of the visual element.

pub fn metadata(&self) -> &Metadata<'a>

Metadata about the vlog directive.

pub fn target(&self) -> &'a str

The name of the target of the directive.

pub fn surface(&self) -> &'a str

The name of the surface of the directive.

pub fn module_path(&self) -> Option<&'a str>

The module path of the message.

pub fn module_path_static(&self) -> Option<&'static str>

The module path of the message, if it is a 'static string.

pub fn file(&self) -> Option<&'a str>

The source file containing the message.

pub fn file_static(&self) -> Option<&'static str>

The source file containing the message, if it is a 'static string.

pub fn line(&self) -> Option<u32>

The line containing the message.