#[non_exhaustive]pub enum PointStyle {
Show 13 variants
FilledCircle,
Circle,
DashedCircle,
FilledSquare,
Square,
DashedSquare,
Point,
PointOutline,
PointSquare,
PointSquareOutline,
PointCross,
PointDiamond,
PointDiamondOutline,
}Expand description
The style of a point type visual. There is two distinct types of styles.
- Circle with absolute size:
FilledCircle,Circle,DashedCircle,FilledSquare,Square,DashedSquare. These are useful to draw circles/squares with a fixed size. In a 3D context these represent spheres/cubes instead. The circle outline uses the correct sphere outline in the used view projection, which means they become ellipses/hyperbolas in a perspective projection. The outlined cube is preferrably drawn as a wireframe cube. - Point billboard marker where the size is determined in screen coordinates instead of the same space as the position coordinates. Zooming in the view will not change their apparent size. These are useful to mark points.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
FilledCircle
A filled circle/sphere. size is the diameter.
Circle
A circle/sphere outline. size is the diameter.
DashedCircle
A dashed circle/sphere outline. size is the diameter.
FilledSquare
A filled square/cube. size is the width.
Square
A square/cube outline/wireframe. size is the width.
DashedSquare
A dashed square/cube outline/wireframe. size is the width.
Point
A filled circle. Dynamically scaled so the size is the pixel size.
PointOutline
A circle outline. Dynamically scaled so the size is the pixel size.
PointSquare
A filled square. Dynamically scaled so the size is the pixel size.
PointSquareOutline
A square outline. Dynamically scaled so the size is the pixel size.
PointCross
An x marker. Dynamically scaled so the size is the pixel size.
PointDiamond
A filled diamond. Dynamically scaled so the size is the pixel size.
PointDiamondOutline
A diamond outline. Dynamically scaled so the size is the pixel size.