Visual

Enum Visual 

pub enum Visual {
    Message,
    Label {
        x: f64,
        y: f64,
        z: f64,
        alignment: TextAlignment,
    },
    Point {
        x: f64,
        y: f64,
        z: f64,
        style: PointStyle,
    },
    Line {
        x1: f64,
        y1: f64,
        z1: f64,
        x2: f64,
        y2: f64,
        z2: f64,
        style: LineStyle,
    },
}
A visual element to be drawn by the vlogger.

Variants



Message

Just a vlog message to be shown in the vlogger instead of the regular vlogs.



Label

A text label placed in space with the message string.

Fields

x: f64

The spacepoint x-coordinate

y: f64

The spacepoint y-coordinate

z: f64

The spacepoint z-coordinate for 3D visualisations.

alignment: TextAlignment

The alignment of the text relative to the spacepoint.



Point

A circle/point placed in space.

Fields

x: f64

The spacepoint x-coordinate

y: f64

The spacepoint y-coordinate

z: f64

The spacepoint z-coordinate for 3D visualisations.

style: PointStyle

The drawing style of the circle/point.



Line

A line placed in space.

Fields

x1: f64

The 1. spacepoint x-coordinate

y1: f64

The 1. spacepoint y-coordinate

z1: f64

The 1. spacepoint z-coordinate for 3D visualisations.

x2: f64

The 2. spacepoint x-coordinate

y2: f64

The 2. spacepoint y-coordinate

z2: f64

The 2. spacepoint z-coordinate for 3D visualisations.

style: LineStyle

The drawing style of the line.