pub trait VLog {
// Required methods
fn enabled(&self, metadata: &Metadata<'_>) -> bool;
fn vlog(&self, record: &Record<'_>);
fn clear(&self, surface: &str);
}Expand description
A trait encapsulating the operations required of a vlogger.
Required Methods
Sourcefn enabled(&self, metadata: &Metadata<'_>) -> bool
fn enabled(&self, metadata: &Metadata<'_>) -> bool
Determines if a vlog command with the specified metadata would be vlogged.
This is used by the vlog_enabled! macro to allow callers to avoid
expensive computation of vlog message arguments if the message would be
discarded anyway.